'''
Defines classes handling the background evolution of the agent-based model

.. autosummary::
   :nosignatures:

   ~scalar_field.ScalarPDEBackground
   ~scalar_field.DiffusionBackground
   

To create a state describing the background, each background class above has
a :meth:`get_state` method. Alternatively, states can be read from data using
the following functions:

.. autosummary::
   :nosignatures:

   ~base.background_state_from_file
   ~base.background_state_from_hdf

.. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
'''

from .base import background_state_from_hdf, background_state_from_file
from .scalar_field import (ScalarBackgroundState, ScalarPDEBackground,
                           DiffusionBackground)
